==> open5gs_2.6.0.tar.xz: BUILD/lib/pfcp/support/cache/tlv-msg-56.py <==
ies = []
ies.append({ "ie_type" : "Report Type", "ie_value" : "Report Type", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall indicate the type of the report."})
ies.append({ "ie_type" : "Downlink Data Report", "ie_value" : "Downlink Data Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates a Downlink Data Report. "})
type_list["Usage Report Session Report Request"]["max_tlv_more"] = "7"
ies.append({ "ie_type" : "Usage Report Session Report Request", "ie_value" : "Usage Report", "presence" : "C", "tlv_more" : "7", "comment" : "This IE shall be present if the Report Type indicates a Usage Report.Several IEs within the same IE type may be present to represent a list of Usage Reports."})
ies.append({ "ie_type" : "Error Indication Report", "ie_value" : "Error Indication Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates an Error Indication Report. "})
ies.append({ "ie_type" : "Load Control Information", "ie_value" : "Load Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "The UP function may include this IE if it supports the load control feature and the feature is activated in the network.See Table7.5.3.3-1."})
ies.append({ "ie_type" : "Overload Control Information", "ie_value" : "Overload Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "During an overload condition, the UP function may include this IE if it supports the overload control feature and the feature is activated in the network.See Table7.5.3.4-1."})
ies.append({ "ie_type" : "Additional Usage Reports Information", "ie_value" : "Additional Usage Reports Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included in one of the additional PFCP Session Report Request messages, if the PFCP Session Modification Response or the PFCP Session Deletion Response indicated that more usage reports would follow (i.e. if the AURI flag was set to 1) (see clause5.2.2.3.1).When present, this IE shall indicate the total number of usage reports that need to be sent in all the additional PFCP Session Report Request messages.This IE may also be included in every additional PFCP Session Report Request message but the last one, with the AURI flag set to 1, to indicate that more usage reports will follow in additional PFCP Session Report Request message."})
ies.append({ "ie_type" : "PFCPSRReq-Flags", "ie_value" : "PFCPSRReq-Flags", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if at least one of the flags is set to 1.-	PSDBU (PFCP Session Deleted By the UP function): if both the CP function and UP function support the EPFAR feature, the UP function may set this flag if the UP function needs to delete the PFCP session, e.g. to report all remaining non-zero usage reports for all URRs in the PFCP Session and the PFCP session is being deleted locally in the UP function.-	the UP function shall also set this flag when sending the last PFCP Session Report Request message after having received a PFCP Session Deletion Request (see clause5.2.2.3.1)."})
ies.append({ "ie_type" : "F-SEID", "ie_value" : "Old CP F-SEID", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the UPF sends the PFCP Session Report Request to a different SMF in an SMF Set. See clauses5.22.2 and 5.22.3.When present, it shall indicate the CP F-SEID assigned by the previous SMF to the PFCP session. "})
ies.append({ "ie_type" : "Packet Rate Status Report", "ie_value" : "Packet Rate Status Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the EPFAR is used (see clause5.18), UP function initiates a PFCP Session release and the CP function has requested in a QER to report the packet rate status when the PFCP session is released.See Table7.5.7.1-1."})
ies.append({ "ie_type" : "TSC Management Information IE within PFCP Session Report Request", "ie_value" : "TSC Management Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates TSC Management Information Report.Several IEs within the same IE type may be present to transfer PMICs for different NW-TT ports."})
ies.append({ "ie_type" : "Session Report", "ie_value" : "Session Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates a Session Report. See Table7.5.8.6-1.Several IEs within the same IE type may be present to represent a list of Session Reports."})
msg_list[key]["ies"] = ies

==> open5gs_2.7.6.4751.5939.202509012026.tar.xz: BUILD/lib/pfcp/support/cache/tlv-msg-56.py <==
ies = []
ies.append({ "ie_type" : "Report Type", "ie_value" : "Report Type", "presence" : "M", "tlv_more" : "0", "comment" : "This IE shall indicate the type of the report."})
ies.append({ "ie_type" : "Downlink Data Report", "ie_value" : "Downlink Data Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates a Downlink Data Report. "})
type_list["Usage Report Session Report Request"]["max_tlv_more"] = "7"
ies.append({ "ie_type" : "Usage Report Session Report Request", "ie_value" : "Usage Report", "presence" : "C", "tlv_more" : "7", "comment" : "This IE shall be present if the Report Type indicates a Usage Report.Several IEs within the same IE type may be present to represent a list of Usage Reports."})
ies.append({ "ie_type" : "Error Indication Report", "ie_value" : "Error Indication Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates an Error Indication Report. "})
ies.append({ "ie_type" : "Load Control Information", "ie_value" : "Load Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "The UP function may include this IE if it supports the load control feature and the feature is activated in the network.See Table7.5.3.3-1."})
ies.append({ "ie_type" : "Overload Control Information", "ie_value" : "Overload Control Information", "presence" : "O", "tlv_more" : "0", "comment" : "During an overload condition, the UP function may include this IE if it supports the overload control feature and the feature is activated in the network.See Table7.5.3.4-1."})
ies.append({ "ie_type" : "Additional Usage Reports Information", "ie_value" : "Additional Usage Reports Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included in one of the additional PFCP Session Report Request messages, if the PFCP Session Modification Response or the PFCP Session Deletion Response indicated that more usage reports would follow (i.e. if the AURI flag was set to 1) (see clause5.2.2.3.1).When present, this IE shall indicate the total number of usage reports that need to be sent in all the additional PFCP Session Report Request messages.This IE may also be included in every additional PFCP Session Report Request message but the last one, with the AURI flag set to 1, to indicate that more usage reports will follow in additional PFCP Session Report Request message."})
ies.append({ "ie_type" : "PFCPSRReq-Flags", "ie_value" : "PFCPSRReq-Flags", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be included if at least one of the flags is set to 1.-	PSDBU (PFCP Session Deleted By the UP function):-	if both the CP function and UP function support the EPFAR feature,the UP function may set this flag if the UP function needs to delete the PFCP session, e.g. to report all remaining non-zero usage reports for all URRs in the PFCP Session and the PFCP session is being deleted locally in the UP function.	-	the UP function shall also set this flag when sending the last PFCP Session Report Request message after having received a PFCP Session Deletion Request (see clause5.2.2.3.1)."})
ies.append({ "ie_type" : "F-SEID", "ie_value" : "Old CP F-SEID", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the UPF sends the PFCP Session Report Request to a different SMF in an SMF Set. See clauses5.22.2 and 5.22.3.When present, it shall indicate the CP F-SEID assigned by the previous SMF to the PFCP session. "})
ies.append({ "ie_type" : "Packet Rate Status Report", "ie_value" : "Packet Rate Status Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the EPFAR is used (see clause5.18), UP function initiates a PFCP Session release and the CP function has requested in a QER to report the packet rate status when the PFCP session is released.See Table7.5.7.1-1."})
ies.append({ "ie_type" : "TSC Management Information IE within PFCP Session Modification Request", "ie_value" : "TSC Management Information", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates TSC Management Information Report.Several IEs within the same IE type may be present to transfer PMICs for different NW-TT ports. (NOTE)."})
ies.append({ "ie_type" : "Session Report", "ie_value" : "Session Report", "presence" : "C", "tlv_more" : "0", "comment" : "This IE shall be present if the Report Type indicates a Session Report. See Table7.5.8.6-1.Several IEs within the same IE type may be present to represent a list of Session Reports."})
ies.append({ "ie_type" : "Cause", "ie_value" : "Cause", "presence" : "O", "tlv_more" : "0", "comment" : "This IE may be present to provide additional reason for sending the PFCP Session Report Request message, e.g. for a UP function initiated PFCP session deletion due to the corresponding L2TP session being terminated."})
msg_list[key]["ies"] = ies
